pub struct SCell<T: ?Sized>(/* private fields */);Expand description
A smart container for objects in recursive data structures
This container contains Rc and therefore clone() will create a new reference to the same instance.
Implementations